/**
	Program to test the spatial filtering.

	Produce an output image (in TIFF format)
	resulted of convolution an input image and a small window
	(this is another small squared image of odd size, 3, 5, etc.)

	Fraga. Jun 11, 2001
	Versin para PGM  Fraga. Jul 25, 2012
**/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "matrix.h"
#include "pnm.h"

extern MATRIX * convolution ( MATRIX *IN, MATRIX *FIL, int ka );

int do_work( char *namein, char *nameout ) 
{
	MATRIX *IN, *OUT, *FIL;
	int **fil;
	

	IN = read_pnm( namein ); 
	if ( IN==NULL ) {
		fprintf( stderr, "ERROR reading %s file\n", namein );
		return -1;
	}
	if ( IN->type != 5 ) {
		fprintf( stderr, "ERROR Bad format. Image must be in 256 grey tones\n");
		return -1;
	}
	FIL = matrix_allocate( 3, 3, sizeof( int ) );
	if ( FIL==NULL ) {
		fprintf( stderr, "ERROR allocating memory\n" );
		return -1;
	}
	fil = (int **)FIL->ptr;
	fil[0][0] = 1; fil[0][1] = 1; fil[0][2] = 1;
	fil[1][0] = 1; fil[1][1] = 1; fil[1][2] = 1;
	fil[2][0] = 1; fil[2][1] = 1; fil[2][2] = 1;

	OUT = convolution( IN, FIL, 9 );
	if ( OUT == NULL ) {
		fprintf( stderr, "ERROR doing convolution\n");
	 	return -1;
	}
	OUT->type=5;
	if ( write_pnm( OUT, nameout ) != 0 )  
        return -1;

	matrix_free( OUT );
	matrix_free( FIL );
	matrix_free( IN );

	return 0;
}

int main( int argc, char *argv[] )
{
	char namein[64], nameout[64];

	if ( argc < 3 ) { 
		fprintf( stderr, "Args: imagen_entrada.pgm nombre_imagen_salida.pgm\n", argv[0] );
		return -1;
	}

	strncpy( namein, argv[1], 64 );
	strncpy( nameout, argv[2], 64 );

	if ( do_work( namein, nameout ) >= 0 ) {
		fprintf( stderr, "OK!!!\n" );
		return 0;
	}
	else {
		fprintf( stderr, "ERROR: Something is wrong!!!\n" );
		exit(1);
	}
	return 0;
}
